@@ -7,7 +7,6 @@
 #include "dolphincontextmenu.h"
 
 #include "dolphin_contextmenusettings.h"
-#include "dolphin_generalsettings.h"
 #include "dolphinmainwindow.h"
 #include "dolphinnewfilemenu.h"
 #include "dolphinplacesmodelsingleton.h"
@@ -16,7 +15,6 @@
 #include "global.h"
 #include "trash/dolphintrash.h"
 #include "views/dolphinview.h"
-#include "views/viewmodecontroller.h"
 
 #include <KActionCollection>
 #include <KFileItemListProperties>
@@ -29,7 +27,6 @@
 #include <KLocalizedString>
 #include <KNewFileMenu>
 #include <KStandardAction>
-#include <kio_version.h>
 
 #include <QApplication>
 #include <QClipboard>
@@ -77,6 +74,8 @@ void DolphinContextMenu::addAllActions()
         m_context |= SearchContext;
     } else if (scheme.contains(QLatin1String("timeline"))) {
         m_context |= TimelineContext;
+    } else if (scheme == QStringLiteral("recentlyused")) {
+        m_context |= RecentlyUsedContext;
     }
 
     if (!m_fileInfo.isNull() && !m_selectedItems.isEmpty()) {
@@ -138,7 +137,7 @@ void DolphinContextMenu::addTrashItemContextMenu()
     addAction(QIcon::fromTheme("restoration"), i18nc("@action:inmenu", "Restore"), [this]() {
         QList<QUrl> selectedUrls;
         selectedUrls.reserve(m_selectedItems.count());
-        for (const KFileItem &item : qAsConst(m_selectedItems)) {
+        for (const KFileItem &item : std::as_const(m_selectedItems)) {
             selectedUrls.append(item.url());
         }
 
@@ -165,17 +164,17 @@ void DolphinContextMenu::addDirectoryItemContextMenu()
         addAction(m_mainWindow->actionCollection()->action(QStringLiteral("open_in_new_window")));
     }
 
+    if (ContextMenuSettings::showOpenInSplitView()) {
+        addAction(m_mainWindow->actionCollection()->action(QStringLiteral("open_in_split_view")));
+    }
+
     // Insert 'Open With' entries
     addOpenWithActions();
 
     // set up 'Create New' menu
-    DolphinNewFileMenu *newFileMenu = new DolphinNewFileMenu(m_mainWindow->actionCollection(), m_mainWindow);
+    DolphinNewFileMenu *newFileMenu = new DolphinNewFileMenu(m_mainWindow->actionCollection()->action(QStringLiteral("create_dir")), m_mainWindow);
     newFileMenu->checkUpToDate();
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 97, 0)
     newFileMenu->setWorkingDirectory(m_fileInfo.url());
-#else
-    newFileMenu->setPopupFiles(QList<QUrl>() << m_fileInfo.url());
-#endif
     newFileMenu->setEnabled(selectedItemsProps.supportsWriting());
     connect(newFileMenu, &DolphinNewFileMenu::fileCreated, newFileMenu, &DolphinNewFileMenu::deleteLater);
     connect(newFileMenu, &DolphinNewFileMenu::directoryCreated, newFileMenu, &DolphinNewFileMenu::deleteLater);
@@ -188,6 +187,25 @@ void DolphinContextMenu::addDirectoryItemContextMenu()
     addSeparator();
 }
 
+void DolphinContextMenu::addOpenParentFolderActions()
+{
+    addAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18nc("@action:inmenu", "Open Path"), [this]() {
+        const QUrl url = m_fileInfo.targetUrl();
+        const QUrl parentUrl = KIO::upUrl(url);
+        m_mainWindow->changeUrl(parentUrl);
+        m_mainWindow->activeViewContainer()->view()->markUrlsAsSelected({url});
+        m_mainWindow->activeViewContainer()->view()->markUrlAsCurrent(url);
+    });
+
+    addAction(QIcon::fromTheme(QStringLiteral("tab-new")), i18nc("@action:inmenu", "Open Path in New Tab"), [this]() {
+        m_mainWindow->openNewTab(KIO::upUrl(m_fileInfo.targetUrl()));
+    });
+
+    addAction(QIcon::fromTheme(QStringLiteral("window-new")), i18nc("@action:inmenu", "Open Path in New Window"), [this]() {
+        Dolphin::openNewWindow({m_fileInfo.targetUrl()}, m_mainWindow, Dolphin::OpenNewWindowFlag::Select);
+    });
+}
+
 void DolphinContextMenu::addItemContextMenu()
 {
     Q_ASSERT(!m_fileInfo.isNull());
@@ -200,22 +218,10 @@ void DolphinContextMenu::addItemContextMenu()
         // single files
         if (m_fileInfo.isDir()) {
             addDirectoryItemContextMenu();
-        } else if (m_context & TimelineContext || m_context & SearchContext) {
+        } else if (m_context & TimelineContext || m_context & SearchContext || m_context & RecentlyUsedContext) {
             addOpenWithActions();
 
-            addAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18nc("@action:inmenu", "Open Path"), [this]() {
-                m_mainWindow->changeUrl(KIO::upUrl(m_fileInfo.url()));
-                m_mainWindow->activeViewContainer()->view()->markUrlsAsSelected({m_fileInfo.url()});
-                m_mainWindow->activeViewContainer()->view()->markUrlAsCurrent(m_fileInfo.url());
-            });
-
-            addAction(QIcon::fromTheme(QStringLiteral("window-new")), i18nc("@action:inmenu", "Open Path in New Window"), [this]() {
-                Dolphin::openNewWindow({m_fileInfo.url()}, m_mainWindow, Dolphin::OpenNewWindowFlag::Select);
-            });
-
-            addAction(QIcon::fromTheme(QStringLiteral("tab-new")), i18nc("@action:inmenu", "Open Path in New Tab"), [this]() {
-                m_mainWindow->openNewTab(KIO::upUrl(m_fileInfo.url()));
-            });
+            addOpenParentFolderActions();
 
             addSeparator();
         } else {
@@ -229,7 +235,7 @@ void DolphinContextMenu::addItemContextMenu()
     } else {
         // multiple files
         bool selectionHasOnlyDirs = true;
-        for (const auto &item : qAsConst(m_selectedItems)) {
+        for (const auto &item : std::as_const(m_selectedItems)) {
             const QUrl &url = DolphinView::openItemAsFolderUrl(item);
             if (url.isEmpty()) {
                 selectionHasOnlyDirs = false;
@@ -281,11 +287,7 @@ void DolphinContextMenu::addViewportContextMenu()
     // Set up and insert 'Create New' menu
     KNewFileMenu *newFileMenu = m_mainWindow->newFileMenu();
     newFileMenu->checkUpToDate();
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 97, 0)
     newFileMenu->setWorkingDirectory(m_baseUrl);
-#else
-    newFileMenu->setPopupFiles(QList<QUrl>() << m_baseUrl);
-#endif
     addMenu(newFileMenu->menu());
 
     // Show "open with" menu items even if the dir is empty, because there are legitimate
