@@ -23,19 +23,16 @@
 #if HAVE_KACTIVITIES
 #include <KActivities/ResourceInstance>
 #endif
+#include <KApplicationTrader>
 #include <KFileItemActions>
 #include <KFilePlacesModel>
-#include <kio_version.h>
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
 #include <KIO/JobUiDelegateFactory>
-#else
-#include <KIO/JobUiDelegate>
-#endif
 #include <KIO/OpenUrlJob>
 #include <KLocalizedString>
 #include <KMessageWidget>
 #include <KProtocolManager>
 #include <KShell>
+#include <kio_version.h>
 
 #include <QApplication>
 #include <QDesktopServices>
@@ -74,9 +71,6 @@ DolphinViewContainer::DolphinViewContainer(const QUrl &url, QWidget *parent)
     , m_statusBarTimer(nullptr)
     , m_statusBarTimestamp()
     , m_autoGrabFocus(true)
-#if HAVE_KACTIVITIES
-    , m_activityResourceInstance(nullptr)
-#endif
 {
     hide();
 
@@ -87,6 +81,7 @@ DolphinViewContainer::DolphinViewContainer(const QUrl &url, QWidget *parent)
     m_searchBox = new DolphinSearchBox(this);
     m_searchBox->hide();
     connect(m_searchBox, &DolphinSearchBox::activated, this, &DolphinViewContainer::activate);
+    connect(m_searchBox, &DolphinSearchBox::openRequest, this, &DolphinViewContainer::openSearchBox);
     connect(m_searchBox, &DolphinSearchBox::closeRequest, this, &DolphinViewContainer::closeSearchBox);
     connect(m_searchBox, &DolphinSearchBox::searchRequest, this, &DolphinViewContainer::startSearching);
     connect(m_searchBox, &DolphinSearchBox::focusViewRequest, this, &DolphinViewContainer::requestFocus);
@@ -135,6 +130,7 @@ DolphinViewContainer::DolphinViewContainer(const QUrl &url, QWidget *parent)
     connect(m_view, &DolphinView::writeStateChanged, this, &DolphinViewContainer::writeStateChanged);
     connect(m_view, &DolphinView::requestItemInfo, this, &DolphinViewContainer::showItemInfo);
     connect(m_view, &DolphinView::itemActivated, this, &DolphinViewContainer::slotItemActivated);
+    connect(m_view, &DolphinView::fileMiddleClickActivated, this, &DolphinViewContainer::slotfileMiddleClickActivated);
     connect(m_view, &DolphinView::itemsActivated, this, &DolphinViewContainer::slotItemsActivated);
     connect(m_view, &DolphinView::redirection, this, &DolphinViewContainer::redirect);
     connect(m_view, &DolphinView::directoryLoadingStarted, this, &DolphinViewContainer::slotDirectoryLoadingStarted);
@@ -190,13 +186,6 @@ DolphinViewContainer::DolphinViewContainer(const QUrl &url, QWidget *parent)
     connect(placesModel, &KFilePlacesModel::rowsRemoved, this, &DolphinViewContainer::slotPlacesModelChanged);
 
     connect(this, &DolphinViewContainer::searchModeEnabledChanged, this, &DolphinViewContainer::captionChanged);
-
-    // Initialize kactivities resource instance
-
-#if HAVE_KACTIVITIES
-    m_activityResourceInstance = new KActivities::ResourceInstance(window()->winId(), url);
-    m_activityResourceInstance->setParent(this);
-#endif
 }
 
 DolphinViewContainer::~DolphinViewContainer()
@@ -220,14 +209,6 @@ void DolphinViewContainer::setActive(bool active)
         m_urlNavigatorConnected->setActive(active);
     }
     m_view->setActive(active);
-
-#if HAVE_KACTIVITIES
-    if (active) {
-        m_activityResourceInstance->notifyFocusedIn();
-    } else {
-        m_activityResourceInstance->notifyFocusedOut();
-    }
-#endif
 }
 
 bool DolphinViewContainer::isActive() const
@@ -593,7 +574,7 @@ void DolphinViewContainer::setUrl(const QUrl &newUrl)
     }
 
 #if HAVE_KACTIVITIES
-    m_activityResourceInstance->setUri(newUrl);
+    KActivities::ResourceInstance::notifyAccessed(newUrl);
 #endif
 }
 
@@ -729,16 +710,44 @@ void DolphinViewContainer::slotItemActivated(const KFileItem &item)
     }
 
     KIO::OpenUrlJob *job = new KIO::OpenUrlJob(item.targetUrl(), item.mimetype());
-#if KIO_VERSION >= QT_VERSION_CHECK(5, 98, 0)
-    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#else
-    job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
-#endif
+    // Auto*Warning*Handling, errors are put in a KMessageWidget by us in slotOpenUrlFinished.
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoWarningHandlingEnabled, this));
     job->setShowOpenOrExecuteDialog(true);
     connect(job, &KIO::OpenUrlJob::finished, this, &DolphinViewContainer::slotOpenUrlFinished);
     job->start();
 }
 
+void DolphinViewContainer::slotfileMiddleClickActivated(const KFileItem &item)
+{
+    KService::List services = KApplicationTrader::queryByMimeType(item.mimetype());
+
+    int indexOfAppToOpenFileWith = 1;
+
+    // executable scripts
+    auto mimeType = item.currentMimeType();
+    if (item.isLocalFile() && mimeType.inherits(QStringLiteral("application/x-executable")) && mimeType.inherits(QStringLiteral("text/plain"))
+        && QFileInfo(item.localPath()).isExecutable()) {
+        KConfigGroup cfgGroup(KSharedConfig::openConfig(QStringLiteral("kiorc")), "Executable scripts");
+        const QString value = cfgGroup.readEntry("behaviourOnLaunch", "alwaysAsk");
+
+        // in case KIO::WidgetsOpenOrExecuteFileHandler::promptUserOpenOrExecute would not open the file
+        if (value != QLatin1String("open")) {
+            indexOfAppToOpenFileWith = 0;
+        }
+    }
+
+    if (services.length() >= indexOfAppToOpenFileWith + 1) {
+        auto service = services.at(indexOfAppToOpenFileWith);
+
+        KIO::ApplicationLauncherJob *job = new KIO::ApplicationLauncherJob(service, this);
+        job->setUrls({item.url()});
+
+        job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+        connect(job, &KIO::OpenUrlJob::finished, this, &DolphinViewContainer::slotOpenUrlFinished);
+        job->start();
+    }
+}
+
 void DolphinViewContainer::slotItemsActivated(const KFileItemList &items)
 {
     Q_ASSERT(items.count() >= 2);
@@ -792,11 +801,13 @@ void DolphinViewContainer::slotUrlNavigatorLocationChanged(const QUrl &url)
     }
 
     if (KProtocolManager::supportsListing(url)) {
-        setSearchModeEnabled(isSearchUrl(url));
+        const bool searchBoxInitialized = isSearchModeEnabled() && m_searchBox->text().isEmpty();
+        setSearchModeEnabled(isSearchUrl(url) || searchBoxInitialized);
+
         m_view->setUrl(url);
         tryRestoreViewState();
 
-        if (m_autoGrabFocus && isActive() && !isSearchUrl(url)) {
+        if (m_autoGrabFocus && isActive() && !isSearchModeEnabled()) {
             // When an URL has been entered, the view should get the focus.
             // The focus must be requested asynchronously, as changing the URL might create
             // a new view widget.
@@ -814,7 +825,11 @@ void DolphinViewContainer::slotUrlNavigatorLocationChanged(const QUrl &url)
         QDesktopServices::openUrl(url);
         redirect(QUrl(), m_urlNavigator->locationUrl(1));
     } else {
-        showMessage(i18nc("@info:status", "Invalid protocol"), Error);
+        if (!url.scheme().isEmpty()) {
+            showMessage(i18nc("@info:status", "Invalid protocol '%1'", url.scheme()), Error);
+        } else {
+            showMessage(i18nc("@info:status", "Invalid protocol"), Error);
+        }
         m_urlNavigator->goBack();
     }
 }
@@ -866,6 +881,11 @@ void DolphinViewContainer::startSearching()
     }
 }
 
+void DolphinViewContainer::openSearchBox()
+{
+    setSearchModeEnabled(true);
+}
+
 void DolphinViewContainer::closeSearchBox()
 {
     setSearchModeEnabled(false);
