@@ -49,7 +49,7 @@ QStringList splitOutsideQuotes(const QString &text)
     //   - Groups with two leading quotes must close both on them (filename:""abc xyz" tuv")
     //   - Groups enclosed in quotes
     //   - Words separated by spaces
-    const QRegularExpression subTermsRegExp("(\\S*?\"\"[^\"]+\"[^\"]+\"+|\\S*?\"[^\"]+\"+|(?<=\\s|^)\\S+(?=\\s|$))");
+    static const QRegularExpression subTermsRegExp("(\\S*?\"\"[^\"]+\"[^\"]+\"+|\\S*?\"[^\"]+\"+|(?<=\\s|^)\\S+(?=\\s|$))");
     auto subTermsMatchIterator = subTermsRegExp.globalMatch(text);
 
     QStringList textParts;
