@@ -7,8 +7,8 @@
 #include "userfeedbacksettingspage.h"
 #include "userfeedback/dolphinfeedbackprovider.h"
 
-#include <KUserFeedback/FeedbackConfigWidget>
-#include <KUserFeedback/Provider>
+#include <KUserFeedbackQt6/FeedbackConfigWidget>
+#include <KUserFeedbackQt6/Provider>
 
 #include <QVBoxLayout>
 
@@ -43,3 +43,5 @@ void UserFeedbackSettingsPage::restoreDefaults()
     feedbackProvider->setTelemetryMode(KUserFeedback::Provider::NoTelemetry);
     feedbackProvider->setSurveyInterval(-1);
 }
+
+#include "moc_userfeedbacksettingspage.cpp"
