@@ -7,14 +7,14 @@
 #include "viewsettingspage.h"
 
 #include "contentdisplaytab.h"
+#include "generalviewsettingspage.h"
 #include "viewsettingstab.h"
-
 #include <KLocalizedString>
 
 #include <QTabWidget>
 #include <QVBoxLayout>
 
-ViewSettingsPage::ViewSettingsPage(QWidget *parent)
+ViewSettingsPage::ViewSettingsPage(const QUrl &url, QWidget *parent)
     : SettingsPageBase(parent)
     , m_tabs()
 {
@@ -23,6 +23,11 @@ ViewSettingsPage::ViewSettingsPage(QWidget *parent)
 
     tabWidget = new QTabWidget(this);
 
+    // General View tab
+    GeneralViewSettingsPage *generalViewPage = new GeneralViewSettingsPage(url, tabWidget);
+    tabWidget->addTab(generalViewPage, QIcon::fromTheme(QStringLiteral("description")), i18nc("@title:tab General View settings", "General"));
+    connect(generalViewPage, &GeneralViewSettingsPage::changed, this, &ViewSettingsPage::changed);
+
     // Content Display Tab
     contentDisplayTab = new ContentDisplayTab(tabWidget);
     tabWidget->addTab(contentDisplayTab,
@@ -45,6 +50,8 @@ ViewSettingsPage::ViewSettingsPage(QWidget *parent)
     tabWidget->addTab(detailsTab, QIcon::fromTheme(QStringLiteral("view-list-tree")), i18nc("@title:tab", "Details"));
     connect(detailsTab, &ViewSettingsTab::changed, this, &ViewSettingsPage::changed);
 
+    m_tabs.append(generalViewPage);
+    m_tabs.append(contentDisplayTab);
     m_tabs.append(iconsTab);
     m_tabs.append(compactTab);
     m_tabs.append(detailsTab);
@@ -58,23 +65,16 @@ ViewSettingsPage::~ViewSettingsPage()
 
 void ViewSettingsPage::applySettings()
 {
-    contentDisplayTab->applySettings();
-
-    for (ViewSettingsTab *tab : qAsConst(m_tabs)) {
+    for (SettingsPageBase *tab : std::as_const(m_tabs)) {
         tab->applySettings();
     }
 }
 
 void ViewSettingsPage::restoreDefaults()
 {
-    if (tabWidget->currentWidget() == contentDisplayTab) {
-        contentDisplayTab->restoreDefaults();
-        return;
-    }
-
-    for (ViewSettingsTab *tab : qAsConst(m_tabs)) {
+    for (SettingsPageBase *tab : std::as_const(m_tabs)) {
         if (tabWidget->currentWidget() == tab) {
-            tab->restoreDefaultSettings();
+            tab->restoreDefaults();
             return;
         }
     }
