@@ -7,7 +7,7 @@
 #ifndef PLACESDATASOURCE_H
 #define PLACESDATASOURCE_H
 
-#include <KUserFeedback/AbstractDataSource>
+#include <KUserFeedbackQt6/AbstractDataSource>
 
 class DolphinMainWindow;
 
@@ -19,7 +19,6 @@ public:
     QString name() const override;
     QString description() const override;
     QVariant data() override;
-
 };
 
 #endif // PLACESDATASOURCE_H
