@@ -20,11 +20,12 @@
 #include <KCharsets>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KIO/Scheduler>
 #include <KLocalizedString>
 #include <KProtocolInfo>
 #include <KProtocolManager>
 
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QMenu>
 
 #define DATA_KEY QStringLiteral("Charset")
@@ -87,7 +88,7 @@ void DolphinRemoteEncoding::fillMenu()
     QMenu *menu = m_menu->menu();
     menu->clear();
 
-    menu->addAction(i18n("Default"), this, SLOT(slotDefault()), 0)->setCheckable(true);
+    menu->addAction(i18n("Default"), this, &DolphinRemoteEncoding::slotDefault)->setCheckable(true);
     for (int i = 0; i < m_encodingDescriptions.size(); i++) {
         QAction *action = new QAction(m_encodingDescriptions.at(i), this);
         action->setCheckable(true);
@@ -96,7 +97,7 @@ void DolphinRemoteEncoding::fillMenu()
     }
     menu->addSeparator();
 
-    menu->addAction(i18n("Reload"), this, SLOT(slotReload()), 0);
+    menu->addAction(i18n("Reload"), this, &DolphinRemoteEncoding::slotReload);
     m_idDefault = m_encodingDescriptions.size() + 2;
 
     connect(menu, &QMenu::triggered, this, &DolphinRemoteEncoding::slotItemSelected);
@@ -210,7 +211,11 @@ void DolphinRemoteEncoding::slotDefault()
 
 void DolphinRemoteEncoding::updateView()
 {
-    KIO::Scheduler::emitReparseSlaveConfiguration();
+    QDBusMessage message =
+        QDBusMessage::createSignal(QStringLiteral("/KIO/Scheduler"), QStringLiteral("org.kde.KIO.Scheduler"), QStringLiteral("reparseSlaveConfiguration"));
+    message << QString();
+    QDBusConnection::sessionBus().send(message);
+
     // Reload the page with the new charset
     m_actionHandler->currentView()->setUrl(m_currentURL);
     m_actionHandler->currentView()->reload();
